Class: MiniTest::Unit

Inherits:
Object show all
Defined in:
lib/minitest/unit.rb,
lib/minitest/benchmark.rb

Defined Under Namespace

Classes: TestCase

Constant Summary collapse

VERSION =

:nodoc:

"2.2.0"
@@out =
$stdout

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeUnit

:nodoc:



823
824
825
826
827
# File 'lib/minitest/unit.rb', line 823

def initialize # :nodoc:
  @report = []
  @errors = @failures = @skips = 0
  @verbose = false
end

Instance Attribute Details

#assertion_countObject

:nodoc:



618
619
620
# File 'lib/minitest/unit.rb', line 618

def assertion_count
  @assertion_count
end

#errorsObject

:nodoc:



617
618
619
# File 'lib/minitest/unit.rb', line 617

def errors
  @errors
end

#failuresObject

:nodoc:



617
618
619
# File 'lib/minitest/unit.rb', line 617

def failures
  @failures
end

#helpObject

:nodoc:



620
621
622
# File 'lib/minitest/unit.rb', line 620

def help
  @help
end

#optionsObject



624
625
626
# File 'lib/minitest/unit.rb', line 624

def options
  @options ||= {}
end

#reportObject

:nodoc:



617
618
619
# File 'lib/minitest/unit.rb', line 617

def report
  @report
end

#runnerObject

Returns the value of attribute runner.



5
6
7
# File 'lib/minitest/benchmark.rb', line 5

def runner
  @runner
end

#skipsObject

:nodoc:



617
618
619
# File 'lib/minitest/unit.rb', line 617

def skips
  @skips
end

#start_timeObject

:nodoc:



619
620
621
# File 'lib/minitest/unit.rb', line 619

def start_time
  @start_time
end

#test_countObject

:nodoc:



618
619
620
# File 'lib/minitest/unit.rb', line 618

def test_count
  @test_count
end

#verboseObject

:nodoc:



621
622
623
# File 'lib/minitest/unit.rb', line 621

def verbose
  @verbose
end

Class Method Details

.after_testsObject

A simple hook allowing you to run a block of code after the tests are done. Eg:

MiniTest::Unit.after_tests { p $debugging_info }


637
638
639
# File 'lib/minitest/unit.rb', line 637

def self.after_tests
  at_exit { at_exit { yield } }
end

.autorunObject

Registers MiniTest::Unit to run tests at process exit



644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
# File 'lib/minitest/unit.rb', line 644

def self.autorun
  at_exit {
    next if $! # don't run if there was an exception

    # the order here is important. The at_exit handler must be
    # installed before anyone else gets a chance to install their
    # own, that way we can be assured that our exit will be last
    # to run (at_exit stacks).
    exit_code = nil

    at_exit { exit false if exit_code && exit_code != 0 }

    exit_code = MiniTest::Unit.new.run ARGV
  } unless @@installed_at_exit
  @@installed_at_exit = true
end

.outObject

Returns the stream to use for output.

DEPRECATED: use ::output instead.



673
674
675
676
# File 'lib/minitest/unit.rb', line 673

def self.out
  warn "::out deprecated, use ::output instead." if $VERBOSE
  output
end

.outputObject

Returns the stream to use for output.



664
665
666
# File 'lib/minitest/unit.rb', line 664

def self.output
  @@out
end

.output=(stream) ⇒ Object

Sets MiniTest::Unit to write output to stream. $stdout is the default output



682
683
684
# File 'lib/minitest/unit.rb', line 682

def self.output= stream
  @@out = stream
end

.pluginsObject

Return all plugins’ run methods (methods that start with “run_”).



706
707
708
709
710
# File 'lib/minitest/unit.rb', line 706

def self.plugins
  @@plugins ||= (["run_tests"] +
                 public_instance_methods(false).
                 grep(/^run_/).map { |s| s.to_s }).uniq
end

.runnerObject

Returns the MiniTest::Unit subclass instance that will be used to run the tests. A MiniTest::Unit instance is the default runner.



699
700
701
# File 'lib/minitest/unit.rb', line 699

def self.runner
  @@runner ||= self.new
end

.runner=(runner) ⇒ Object

Tells MiniTest::Unit to delegate to runner, an instance of a MiniTest::Unit subclass, when MiniTest::Unit#run is called.



690
691
692
# File 'lib/minitest/unit.rb', line 690

def self.runner= runner
  @@runner = runner
end

Instance Method Details

#_run(args = []) ⇒ Object

Top level driver, controls all output and filtering.



882
883
884
885
886
887
888
889
890
891
892
893
894
895
# File 'lib/minitest/unit.rb', line 882

def _run args = []
  self.options = process_args args

  puts "Run options: #{help}"

  self.class.plugins.each do |plugin|
    send plugin
    break unless report.empty?
  end

  return failures + errors if @test_count > 0 # or return nil...
rescue Interrupt
  abort 'Interrupted'
end

#_run_anything(type) ⇒ Object



724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
# File 'lib/minitest/unit.rb', line 724

def _run_anything type
  suites = TestCase.send "#{type}_suites"
  return if suites.empty?

  start = Time.now

  puts
  puts "# Running #{type}s:"
  puts

  @test_count, @assertion_count = 0, 0
  sync = output.respond_to? :"sync=" # stupid emacs
  old_sync, output.sync = output.sync, true if sync

  results = _run_suites suites, type

  @test_count      = results.inject(0) { |sum, (tc, _)| sum + tc }
  @assertion_count = results.inject(0) { |sum, (_, ac)| sum + ac }

  output.sync = old_sync if sync

  t = Time.now - start

  puts
  puts
  puts "Finished #{type}s in %.6fs, %.4f tests/s, %.4f assertions/s." %
    [t, test_count / t, assertion_count / t]

  report.each_with_index do |msg, i|
    puts "\n%3d) %s" % [i + 1, msg]
  end

  puts

  status
end

#_run_suite(suite, type) ⇒ Object



765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
# File 'lib/minitest/unit.rb', line 765

def _run_suite suite, type
  header = "#{type}_suite_header"
  puts send(header, suite) if respond_to? header

  filter = options[:filter] || '/./'
  filter = Regexp.new $1 if filter =~ /\/(.*)\//

  assertions = suite.send("#{type}_methods").grep(filter).map { |method|
    inst = suite.new method
    inst._assertions = 0

    print "#{suite}##{method} = " if @verbose

    @start_time = Time.now
    result = inst.run self
    time = Time.now - @start_time

    print "%.2f s = " % time if @verbose
    print result
    puts if @verbose

    inst._assertions
  }

  return assertions.size, assertions.inject(0) { |sum, n| sum + n }
end

#_run_suites(suites, type) ⇒ Object



761
762
763
# File 'lib/minitest/unit.rb', line 761

def _run_suites suites, type
  suites.map { |suite| _run_suite suite, type }
end

#benchmark_suite_header(suite) ⇒ Object

:nodoc:



11
12
13
# File 'lib/minitest/benchmark.rb', line 11

def benchmark_suite_header suite # :nodoc:
  "\n#{suite}\t#{suite.bench_range.join("\t")}"
end

#location(e) ⇒ Object

:nodoc:



792
793
794
795
796
797
798
799
# File 'lib/minitest/unit.rb', line 792

def location e # :nodoc:
  last_before_assertion = ""
  e.backtrace.reverse_each do |s|
    break if s =~ /in .(assert|refute|flunk|pass|fail|raise|must|wont)/
    last_before_assertion = s
  end
  last_before_assertion.sub(/:in .*$/, '')
end

#outputObject



712
713
714
# File 'lib/minitest/unit.rb', line 712

def output
  self.class.output
end

:nodoc:



720
721
722
# File 'lib/minitest/unit.rb', line 720

def print *a # :nodoc:
  output.print(*a)
end

#process_args(args = []) ⇒ Object



829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
# File 'lib/minitest/unit.rb', line 829

def process_args args = []
  options = {}
  orig_args = args.dup

  OptionParser.new do |opts|
    opts.banner  = 'minitest options:'
    opts.version = MiniTest::Unit::VERSION

    opts.on '-h', '--help', 'Display this help.' do
      puts opts
      exit
    end

    opts.on '-s', '--seed SEED', Integer, "Sets random seed" do |m|
      options[:seed] = m.to_i
    end

    opts.on '-v', '--verbose', "Verbose. Show progress processing files." do
      options[:verbose] = true
    end

    opts.on '-n', '--name PATTERN', "Filter test names on pattern." do |a|
      options[:filter] = a
    end

    opts.parse! args
    orig_args -= args
  end

  unless options[:seed] then
    srand
    options[:seed] = srand % 0xFFFF
    orig_args << "--seed" << options[:seed].to_s
  end

  srand options[:seed]

  self.verbose = options[:verbose]
  @help = orig_args.map { |s| s =~ /[\s|&<>$()]/ ? s.inspect : s }.join " "

  options
end

#puke(klass, meth, e) ⇒ Object

Writes status for failed test meth in klass which finished with exception e



805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
# File 'lib/minitest/unit.rb', line 805

def puke klass, meth, e
  e = case e
      when MiniTest::Skip then
        @skips += 1
        return "S" unless @verbose
        "Skipped:\n#{meth}(#{klass}) [#{location e}]:\n#{e.message}\n"
      when MiniTest::Assertion then
        @failures += 1
        "Failure:\n#{meth}(#{klass}) [#{location e}]:\n#{e.message}\n"
      else
        @errors += 1
        bt = MiniTest::filter_backtrace(e.backtrace).join "\n    "
        "Error:\n#{meth}(#{klass}):\n#{e.class}: #{e.message}\n    #{bt}\n"
      end
  @report << e
  e[0, 1]
end

#puts(*a) ⇒ Object

:nodoc:



716
717
718
# File 'lib/minitest/unit.rb', line 716

def puts *a  # :nodoc:
  output.puts(*a)
end

#run(args = []) ⇒ Object

Begins the full test run. Delegates to runner‘s #_run method.



875
876
877
# File 'lib/minitest/unit.rb', line 875

def run args = []
  self.class.runner._run(args)
end

#run_benchmarksObject

:nodoc:



7
8
9
# File 'lib/minitest/benchmark.rb', line 7

def run_benchmarks # :nodoc:
  _run_anything :benchmark
end

#run_testsObject

Runs test suites matching filter.



900
901
902
# File 'lib/minitest/unit.rb', line 900

def run_tests
  _run_anything :test
end

#status(io = self.output) ⇒ Object

Writes status to io



907
908
909
910
# File 'lib/minitest/unit.rb', line 907

def status io = self.output
  format = "%d tests, %d assertions, %d failures, %d errors, %d skips"
  io.puts format % [test_count, assertion_count, failures, errors, skips]
end