Module: MiniTest::Unit::Guard

Included in:
TestCase, TestCase
Defined in:
lib/minitest/unit.rb

Overview

Provides a simple set of guards that you can use in your tests to skip execution if it is not applicable. These methods are mixed into TestCase as both instance and class methods so you can use them inside or outside of the test methods.

def test_something_for_mri
skip "bug 1234"  if jruby?
# ...
end

if windows? then
# ... lots of test methods ...
end

Instance Method Summary collapse

Instance Method Details

#jruby?(platform = RUBY_PLATFORM) ⇒ Boolean

Is this running on jruby?

Returns:

  • (Boolean)


1008
1009
1010
# File 'lib/minitest/unit.rb', line 1008

def jruby? platform = RUBY_PLATFORM
  "java" == platform
end

#mri?(platform = RUBY_DESCRIPTION) ⇒ Boolean

Is this running on mri?

Returns:

  • (Boolean)


1015
1016
1017
# File 'lib/minitest/unit.rb', line 1015

def mri? platform = RUBY_DESCRIPTION
  /^ruby/ =~ platform
end

#rubinius?(platform = defined?(RUBY_ENGINE) && RUBY_ENGINE) ⇒ Boolean

Is this running on rubinius?

Returns:

  • (Boolean)


1022
1023
1024
# File 'lib/minitest/unit.rb', line 1022

def rubinius? platform = defined?(RUBY_ENGINE) && RUBY_ENGINE
  "rbx" == platform
end

#windows?(platform = RUBY_PLATFORM) ⇒ Boolean

Is this running on windows?

Returns:

  • (Boolean)


1029
1030
1031
# File 'lib/minitest/unit.rb', line 1029

def windows? platform = RUBY_PLATFORM
  /mswin|mingw/ =~ platform
end