Method: Minitest::Test.i_suck_and_my_tests_are_order_dependent!
- Defined in:
- lib/minitest/test.rb
.i_suck_and_my_tests_are_order_dependent! ⇒ Object
Call this at the top of your tests when you absolutely positively need to have ordered tests. In doing so, you're admitting that you suck and your tests are weak.
31 32 33 34 35 36 |
# File 'lib/minitest/test.rb', line 31 def self.i_suck_and_my_tests_are_order_dependent! class << self undef_method :run_order if method_defined? :run_order define_method :run_order do :alpha end end end |