Method: Minitest::TestTask#name
- Defined in:
- lib/minitest/test_task.rb
#name ⇒ Object
The name of the task and base name for the other tasks generated.
88 89 90 |
# File 'lib/minitest/test_task.rb', line 88 def name @name end |
The name of the task and base name for the other tasks generated.
88 89 90 |
# File 'lib/minitest/test_task.rb', line 88 def name @name end |