Class: Minitest::AbstractReporter

Inherits:
Object
  • Object
show all
Defined in:
lib/minitest.rb

Overview

Defines the API for Reporters. Subclass this and override whatever you want. Go nuts.

Direct Known Subclasses

CompositeReporter, Reporter

Instance Method Summary collapse

Constructor Details

#initializeAbstractReporter

:nodoc:



654
655
656
# File 'lib/minitest.rb', line 654

def initialize # :nodoc:
  @mutex = Mutex.new
end

Instance Method Details

#passed?Boolean

Did this run pass?

Returns:

  • (Boolean)


689
690
691
# File 'lib/minitest.rb', line 689

def passed?
  true
end

#prerecord(klass, name) ⇒ Object

About to start running a test. This allows a reporter to show that it is starting or that we are in the middle of a test run.



668
669
# File 'lib/minitest.rb', line 668

def prerecord klass, name
end

#record(result) ⇒ Object

Output and record the result of the test. Call result#result_code to get the result character string. Stores the result of the run if the run did not pass.



677
678
# File 'lib/minitest.rb', line 677

def record result
end

#reportObject

Outputs the summary of the run.



683
684
# File 'lib/minitest.rb', line 683

def report
end

#startObject

Starts reporting on the run.



661
662
# File 'lib/minitest.rb', line 661

def start
end

#synchronize(&block) ⇒ Object

:nodoc:



693
694
695
# File 'lib/minitest.rb', line 693

def synchronize(&block) # :nodoc:
  @mutex.synchronize(&block)
end