Module: Minitest::Assertions

Included in:
Test
Defined in:
lib/minitest/assertions.rb

Overview

Minitest Assertions. All assertion methods accept a msg which is printed if the assertion fails.

Protocol: Nearly everything here boils up to assert, which expects to be able to increment an instance accessor named assertions. This is not provided by Assertions and must be provided by the thing including Assertions. See Minitest::Runnable for an example.

Constant Summary collapse

UNDEFINED =

:nodoc:

Object.new
NO_RE_MSG =
"class or module required for rescue clause. Got %p"

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.diffObject

Returns the diff command to use in #diff. Tries to intelligently figure out what diff to use.



27
28
29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/minitest/assertions.rb', line 27

def self.diff
  return @diff if defined? @diff

  @diff = if (RbConfig::CONFIG["host_os"] =~ /mswin|mingw/ and
              system "diff.exe", __FILE__, __FILE__) then
            "diff.exe -u"
          elsif system "gdiff", __FILE__, __FILE__ then
            "gdiff -u" # solaris and kin suck
          elsif system "diff", __FILE__, __FILE__ then
            "diff -u"
          else
            nil
          end
end

.diff=(o) ⇒ Object

Set the diff command to use in #diff.



45
46
47
# File 'lib/minitest/assertions.rb', line 45

def self.diff= o
  @diff = o
end

Instance Method Details

#_synchronizeObject

:nodoc:



181
182
183
# File 'lib/minitest/assertions.rb', line 181

def _synchronize # :nodoc:
  yield
end

#_whereObject

:nodoc:



193
194
195
196
# File 'lib/minitest/assertions.rb', line 193

def _where # :nodoc:
  Minitest.filter_backtrace(caller).first
    .split(":in ", 2).first # clean up noise
end

#assert(test, msg = nil) ⇒ Object

Fails unless test is truthy.



171
172
173
174
175
176
177
178
179
# File 'lib/minitest/assertions.rb', line 171

def assert test, msg = nil
  self.assertions += 1
  unless test then
    msg ||= "Expected #{mu_pp test} to be truthy."
    msg = msg.call if Proc === msg
    raise Minitest::Assertion, msg
  end
  true
end

#assert_empty(obj, msg = nil) ⇒ Object

Fails unless obj is empty.



188
189
190
191
# File 'lib/minitest/assertions.rb', line 188

def assert_empty obj, msg = nil
  msg = message(msg) { "Expected #{mu_pp(obj)} to be empty" }
  assert_predicate obj, :empty?, msg
end

#assert_equal(exp, act, msg = nil) ⇒ Object

Fails unless exp == act printing the difference between the two, if possible.

If there is no visible difference but the assertion fails, you should suspect that your #== is buggy, or your inspect output is missing crucial details. For nicer structural diffing, set Minitest::Test.make_my_diffs_pretty!

For floats use assert_in_delta.

See also: Minitest::Assertions.diff



211
212
213
214
215
216
217
# File 'lib/minitest/assertions.rb', line 211

def assert_equal exp, act, msg = nil
  msg = message(msg, nil) { diff exp, act }

  refute_nil exp, message { "Use assert_nil if expecting nil" } if exp.nil? # don't count

  assert exp == act, msg
end

#assert_in_delta(exp, act, delta = 0.001, msg = nil) ⇒ Object

For comparing Floats. Fails unless exp and act are within delta of each other.

assert_in_delta Math::PI, (22.0 / 7.0), 0.01


225
226
227
228
229
230
231
# File 'lib/minitest/assertions.rb', line 225

def assert_in_delta exp, act, delta = 0.001, msg = nil
  n = (exp - act).abs
  msg = message(msg) {
    "Expected |#{exp} - #{act}| (#{n}) to be <= #{delta}"
  }
  assert delta >= n, msg
end

#assert_in_epsilon(exp, act, epsilon = 0.001, msg = nil) ⇒ Object

For comparing Floats. Fails unless exp and act have a relative error less than epsilon.



237
238
239
# File 'lib/minitest/assertions.rb', line 237

def assert_in_epsilon exp, act, epsilon = 0.001, msg = nil
  assert_in_delta exp, act, [exp.abs, act.abs].min * epsilon, msg
end

#assert_includes(collection, obj, msg = nil) ⇒ Object

Fails unless collection includes obj.



244
245
246
247
248
249
# File 'lib/minitest/assertions.rb', line 244

def assert_includes collection, obj, msg = nil
  msg = message(msg) {
    "Expected #{mu_pp collection} to include #{mu_pp obj}"
  }
  assert_operator collection, :include?, obj, msg
end

#assert_instance_of(cls, obj, msg = nil) ⇒ Object

Fails unless obj is an instance of cls.



254
255
256
257
258
259
260
# File 'lib/minitest/assertions.rb', line 254

def assert_instance_of cls, obj, msg = nil
  msg = message(msg) {
    "Expected #{mu_pp obj} to be an instance of #{cls}, not #{obj.class}"
  }

  assert obj.instance_of?(cls), msg
end

#assert_kind_of(cls, obj, msg = nil) ⇒ Object

Fails unless obj is a kind of cls.



265
266
267
268
269
270
271
# File 'lib/minitest/assertions.rb', line 265

def assert_kind_of cls, obj, msg = nil
  msg = message(msg) {
    "Expected #{mu_pp obj} to be a kind of #{cls}, not #{obj.class}"
  }

  assert obj.kind_of?(cls), msg
end

#assert_match(matcher, obj, msg = nil) ⇒ Object

Fails unless matcher =~ obj.



276
277
278
279
280
281
282
283
# File 'lib/minitest/assertions.rb', line 276

def assert_match matcher, obj, msg = nil
  msg = message(msg) { "Expected #{mu_pp matcher} to match #{mu_pp obj}" }
  assert_respond_to matcher, :=~
  matcher = Regexp.new Regexp.escape matcher if String === matcher
  assert matcher =~ obj, msg

  Regexp.last_match
end

#assert_nil(obj, msg = nil) ⇒ Object

Fails unless obj is nil



288
289
290
291
# File 'lib/minitest/assertions.rb', line 288

def assert_nil obj, msg = nil
  msg = message(msg) { "Expected #{mu_pp obj} to be nil" }
  assert obj.nil?, msg
end

#assert_operator(o1, op, o2 = UNDEFINED, msg = nil) ⇒ Object

For testing with binary operators. Eg:

assert_operator 5, :<=, 4


298
299
300
301
302
303
# File 'lib/minitest/assertions.rb', line 298

def assert_operator o1, op, o2 = UNDEFINED, msg = nil
  return assert_predicate o1, op, msg if UNDEFINED == o2
  assert_respond_to o1, op
  msg = message(msg) { "Expected #{mu_pp o1} to be #{op} #{mu_pp o2}" }
  assert o1.__send__(op, o2), msg
end

#assert_output(stdout = nil, stderr = nil) ⇒ Object

Fails if stdout or stderr do not output the expected results. Pass in nil if you don’t care about that streams output. Pass in “” if you require it to be silent. Pass in a regexp if you want to pattern match.

assert_output(/hey/) { method_with_output }

NOTE: this uses #capture_io, not #capture_subprocess_io.

See also: #assert_silent



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/minitest/assertions.rb', line 317

def assert_output stdout = nil, stderr = nil
  flunk "assert_output requires a block to capture output." unless
    block_given?

  out, err = capture_io do
    yield
  end

  err_msg = Regexp === stderr ? :assert_match : :assert_equal if stderr
  out_msg = Regexp === stdout ? :assert_match : :assert_equal if stdout

  y = send err_msg, stderr, err, "In stderr" if err_msg
  x = send out_msg, stdout, out, "In stdout" if out_msg

  (!stdout || x) && (!stderr || y)
rescue Assertion
  raise
rescue => e
  raise UnexpectedError, e
end

#assert_path_exists(path, msg = nil) ⇒ Object

Fails unless path exists.



341
342
343
344
# File 'lib/minitest/assertions.rb', line 341

def assert_path_exists path, msg = nil
  msg = message(msg) { "Expected path '#{path}' to exist" }
  assert File.exist?(path), msg
end

#assert_patternObject

For testing with pattern matching (only supported with Ruby 3.0 and later)

# pass
assert_pattern { [1,2,3] => [Integer, Integer, Integer] }

# fail "length mismatch (given 3, expected 1)"
assert_pattern { [1,2,3] => [Integer] }

The bare => pattern will raise a NoMatchingPatternError on failure, which would normally be counted as a test error. This assertion rescues NoMatchingPatternError and generates a test failure. Any other exception will be raised as normal and generate a test error.



360
361
362
363
364
365
366
367
# File 'lib/minitest/assertions.rb', line 360

def assert_pattern
  flunk "assert_pattern requires a block to capture errors." unless block_given?

  yield
  pass
rescue NoMatchingPatternError => e
  flunk e.message
end

#assert_predicate(o1, op, msg = nil) ⇒ Object

For testing with predicates. Eg:

assert_predicate str, :empty?

This is really meant for specs and is front-ended by assert_operator:

str.must_be :empty?


378
379
380
381
382
# File 'lib/minitest/assertions.rb', line 378

def assert_predicate o1, op, msg = nil
  assert_respond_to o1, op, include_all:true
  msg = message(msg) { "Expected #{mu_pp o1} to be #{op}" }
  assert o1.__send__(op), msg
end

#assert_raises(*exp) ⇒ Object

Fails unless the block raises one of exp. Returns the exception matched so you can check the message, attributes, etc.

exp takes an optional message on the end to help explain failures and defaults to StandardError if no exception class is passed. Eg:

assert_raises(CustomError) { method_with_custom_error }

With custom error message:

assert_raises(CustomError, 'This should have raised CustomError') { method_with_custom_error }

Using the returned object:

error = assert_raises(CustomError) do
  raise CustomError, 'This is really bad'
end

assert_equal 'This is really bad', error.message

Raises:

  • (TypeError)


408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/minitest/assertions.rb', line 408

def assert_raises *exp
  flunk "assert_raises requires a block to capture errors." unless
    block_given?

  msg = "#{exp.pop}.\n" if String === exp.last
  exp << StandardError if exp.empty?

  # TODO: remove this if https://bugs.ruby-lang.org/issues/22007 gets fixed
  raise TypeError, NO_RE_MSG % [exp] unless exp.all? Module

  begin
    yield
  rescue *exp => e
    pass # count assertion
    return e
  rescue Minitest::Assertion # incl Skip & UnexpectedError
    # don't count assertion
    raise
  rescue SignalException, SystemExit
    raise
  rescue Exception => e
    flunk proc {
      exception_details(e, "#{msg}#{mu_pp exp} exception expected, not")
    }
  end

  exp = exp.first if exp.size == 1

  flunk "#{msg}#{mu_pp exp} expected but nothing was raised."
end

#assert_respond_to(obj, meth, msg = nil, include_all: false) ⇒ Object

Fails unless obj responds to meth. include_all defaults to false to match Object#respond_to?



443
444
445
446
# File 'lib/minitest/assertions.rb', line 443

def assert_respond_to obj, meth, msg = nil, include_all: false
  msg = message(msg) { "Expected #{mu_pp obj} (#{obj.class}) to respond to ##{meth}" }
  assert obj.respond_to?(meth, include_all), msg
end

#assert_same(exp, act, msg = nil) ⇒ Object

Fails unless exp and act are #equal?



451
452
453
454
455
456
457
458
459
460
# File 'lib/minitest/assertions.rb', line 451

def assert_same exp, act, msg = nil
  msg = message(msg) {
    data = [mu_pp(act), act.object_id, mu_pp(exp), exp.object_id]
    "Expected %s (oid=%d) to be the same as %s (oid=%d)" % data
  }

  refute_nil exp, message { "Use assert_nil if expecting nil" } if exp.nil? # don't count

  assert exp.equal?(act), msg
end

#assert_silentObject

Fails if the block outputs anything to stderr or stdout.

See also: #assert_output



467
468
469
470
471
# File 'lib/minitest/assertions.rb', line 467

def assert_silent
  assert_output "", "" do
    yield
  end
end

#assert_throws(sym, msg = nil) ⇒ Object

Fails unless the block throws sym



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
# File 'lib/minitest/assertions.rb', line 476

def assert_throws sym, msg = nil
  default = "Expected #{mu_pp sym} to have been thrown"
  caught = true
  value = catch sym do
    begin
      yield
    rescue ArgumentError => e     # 1.9+ exception
      raise e unless e.message.include? "uncaught throw"
      default += ", not #{e.message.split(/ /).last}"
    end
    caught = false
  end

  assert caught, message(msg) { default }
  value
rescue Assertion
  raise
rescue => e
  raise UnexpectedError, e
end

#capture_ioObject

Captures $stdout and $stderr into strings:

out, err = capture_io do
  puts "Some info"
  warn "You did a bad thing"
end

assert_match %r%info%, out
assert_match %r%bad%, err

NOTE: For efficiency, this method uses StringIO and does not capture IO for subprocesses. Use #capture_subprocess_io for that.



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/minitest/assertions.rb', line 512

def capture_io
  _synchronize do
    begin
      captured_stdout, captured_stderr = StringIO.new, StringIO.new

      orig_stdout, orig_stderr = $stdout, $stderr
      $stdout, $stderr         = captured_stdout, captured_stderr

      yield

      return captured_stdout.string, captured_stderr.string
    ensure
      $stdout = orig_stdout
      $stderr = orig_stderr
    end
  end
end

#capture_subprocess_ioObject

Captures $stdout and $stderr into strings, using Tempfile to ensure that subprocess IO is captured as well.

out, err = capture_subprocess_io do
  system "echo Some info"
  system "echo You did a bad thing 1>&2"
end

assert_match %r%info%, out
assert_match %r%bad%, err

NOTE: This method is approximately 10x slower than #capture_io so only use it when you need to test the output of a subprocess.



545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/minitest/assertions.rb', line 545

def capture_subprocess_io
  _synchronize do
    begin
      require "tempfile"

      captured_stdout, captured_stderr = Tempfile.new("out"), Tempfile.new("err")

      orig_stdout, orig_stderr = $stdout.dup, $stderr.dup
      $stdout.reopen captured_stdout
      $stderr.reopen captured_stderr

      yield

      $stdout.rewind
      $stderr.rewind

      return captured_stdout.read, captured_stderr.read
    ensure
      $stdout.reopen orig_stdout
      $stderr.reopen orig_stderr

      orig_stdout.close
      orig_stderr.close
      captured_stdout.close!
      captured_stderr.close!
    end
  end
end

#diff(exp, act) ⇒ Object

Returns a diff between exp and act. If there is no known diff command or if it doesn’t make sense to diff the output (single line, short output), then it simply returns a basic comparison between the two.

See things_to_diff for more info.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/minitest/assertions.rb', line 57

def diff exp, act
  result = nil

  expect, butwas = things_to_diff exp, act

  return "Expected: #{mu_pp exp}\n  Actual: #{mu_pp act}" unless
    expect

  Tempfile.create "expect" do |a|
    a.puts expect
    a.flush

    Tempfile.create "butwas" do |b|
      b.puts butwas
      b.flush

      result = `#{Minitest::Assertions.diff} #{a.path} #{b.path}`
      result.sub!(/^\-\-\- .+/, "--- expected")
      result.sub!(/^\+\+\+ .+/, "+++ actual")

      if result.empty? then
        klass = exp.class
        result = [
                   "No visible difference in the #{klass}#inspect output.\n",
                   "You should look at the implementation of #== on ",
                   "#{klass} or its members.\n",
                   expect,
                 ].join
      end
    end
  end

  result
end

#exception_details(e, msg) ⇒ Object

Returns details for exception e



577
578
579
580
581
582
583
584
585
586
# File 'lib/minitest/assertions.rb', line 577

def exception_details e, msg
  [
    msg,
    "Class: <#{e.class}>",
    "Message: <#{e.message.inspect}>",
    "---Backtrace---",
    Minitest.filter_backtrace(e.backtrace),
    "---------------",
  ].join "\n"
end

#fail_after(y, m, d, msg) ⇒ Object

Fails after a given date (in the local time zone). This allows you to put time-bombs in your tests if you need to keep something around until a later date lest you forget about it.



593
594
595
# File 'lib/minitest/assertions.rb', line 593

def fail_after y, m, d, msg
  flunk msg if Time.now > Time.local(y, m, d)
end

#flunk(msg = nil) ⇒ Object

Fails with msg.



600
601
602
603
# File 'lib/minitest/assertions.rb', line 600

def flunk msg = nil
  msg ||= "Epic Fail!"
  assert false, msg
end

#message(msg = nil, ending = ".", &default) ⇒ Object

Returns a proc that delays generation of an output message. If msg is a proc (eg, from another message call) return msg as-is. Otherwise, return a proc that will output msg along with the value of the result of the block passed to message.



611
612
613
614
615
616
617
# File 'lib/minitest/assertions.rb', line 611

def message msg = nil, ending = ".", &default
  return msg if Proc === msg
  proc {
    custom_message = "#{msg}.\n" unless msg.nil? or msg.to_s.empty?
    "#{custom_message}#{default.call}#{ending}"
  }
end

#mu_pp(obj) ⇒ Object

This returns a human-readable version of obj. By default #inspect is called. You can override this to use #pretty_inspect if you want.

See Minitest::Test.make_my_diffs_pretty!



127
128
129
130
131
132
133
134
135
136
137
# File 'lib/minitest/assertions.rb', line 127

def mu_pp obj
  s = obj.inspect.encode Encoding.default_external

  return s unless String === obj &&
    (obj.encoding != Encoding.default_external || !obj.valid_encoding?)

  enc = "# encoding: #{obj.encoding}"
  val = "#    valid: #{obj.valid_encoding?}"

  [enc, val, s].join "\n"
end

#mu_pp_for_diff(obj) ⇒ Object

This returns a diff-able more human-readable version of obj. This differs from the regular mu_pp because it expands escaped newlines and makes hex-values (like object_ids) generic. This uses mu_pp to do the first pass and then cleans it up.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/minitest/assertions.rb', line 145

def mu_pp_for_diff obj
  str = mu_pp obj

  # both '\n' & '\\n' (_after_ mu_pp (aka inspect))
  single = str.match?(/(?<!\\|^)\\n/)
  double = str.match?(/(?<=\\|^)\\n/)

  process =
    if single ^ double then
      if single then
        lambda { |s| s == "\\n"   ? "\n"    : s } # unescape
      else
        lambda { |s| s == "\\\\n" ? "\\n\n" : s } # unescape a bit, add nls
      end
    else
      :itself                                     # leave it alone
    end

  str
    .gsub(/\\?\\n/, &process)
    .gsub(/:0x[a-fA-F0-9]{4,}/m, ":0xXXXXXX") # anonymize hex values
end

#pass(_msg = nil) ⇒ Object

used for counting assertions



622
623
624
# File 'lib/minitest/assertions.rb', line 622

def pass _msg = nil
  assert true
end

#refute(test, msg = nil) ⇒ Object

Fails if test is truthy.



629
630
631
632
# File 'lib/minitest/assertions.rb', line 629

def refute test, msg = nil
  msg ||= message { "Expected #{mu_pp test} to not be truthy" }
  assert !test, msg
end

#refute_empty(obj, msg = nil) ⇒ Object

Fails if obj is empty.



637
638
639
640
# File 'lib/minitest/assertions.rb', line 637

def refute_empty obj, msg = nil
  msg = message(msg) { "Expected #{mu_pp obj} to not be empty" }
  refute_predicate obj, :empty?, msg
end

#refute_equal(exp, act, msg = nil) ⇒ Object

Fails if exp == act.

For floats use refute_in_delta.



647
648
649
650
651
652
# File 'lib/minitest/assertions.rb', line 647

def refute_equal exp, act, msg = nil
  msg = message(msg) {
    "Expected #{mu_pp act} to not be equal to #{mu_pp exp}"
  }
  refute exp == act, msg
end

#refute_in_delta(exp, act, delta = 0.001, msg = nil) ⇒ Object

For comparing Floats. Fails if exp is within delta of act.

refute_in_delta Math::PI, (22.0 / 7.0)


659
660
661
662
663
664
665
# File 'lib/minitest/assertions.rb', line 659

def refute_in_delta exp, act, delta = 0.001, msg = nil
  n = (exp - act).abs
  msg = message(msg) {
    "Expected |#{exp} - #{act}| (#{n}) to not be <= #{delta}"
  }
  refute delta >= n, msg
end

#refute_in_epsilon(exp, act, epsilon = 0.001, msg = nil) ⇒ Object

For comparing Floats. Fails if exp and act have a relative error less than epsilon.



671
672
673
# File 'lib/minitest/assertions.rb', line 671

def refute_in_epsilon exp, act, epsilon = 0.001, msg = nil
  refute_in_delta exp, act, [exp.abs, act.abs].min * epsilon, msg
end

#refute_includes(obj, sub, msg = nil) ⇒ Object

Fails if obj includes sub.



678
679
680
681
# File 'lib/minitest/assertions.rb', line 678

def refute_includes obj, sub, msg = nil
  msg = message(msg) { "Expected #{mu_pp obj} to not include #{mu_pp sub}" }
  refute_operator obj, :include?, sub, msg
end

#refute_instance_of(cls, obj, msg = nil) ⇒ Object

Fails if obj is an instance of cls.



686
687
688
689
690
691
# File 'lib/minitest/assertions.rb', line 686

def refute_instance_of cls, obj, msg = nil
  msg = message(msg) {
    "Expected #{mu_pp obj} to not be an instance of #{cls}"
  }
  refute obj.instance_of?(cls), msg
end

#refute_kind_of(cls, obj, msg = nil) ⇒ Object

Fails if obj is a kind of cls.



696
697
698
699
# File 'lib/minitest/assertions.rb', line 696

def refute_kind_of cls, obj, msg = nil
  msg = message(msg) { "Expected #{mu_pp obj} to not be a kind of #{cls}" }
  refute obj.kind_of?(cls), msg
end

#refute_match(matcher, obj, msg = nil) ⇒ Object

Fails if matcher =~ obj.



704
705
706
707
708
# File 'lib/minitest/assertions.rb', line 704

def refute_match matcher, obj, msg = nil
  msg = message(msg) { "Expected #{mu_pp matcher} to not match #{mu_pp obj}" }
  matcher = Regexp.new Regexp.escape matcher if String === matcher
  refute_operator matcher, :=~, obj, msg
end

#refute_nil(obj, msg = nil) ⇒ Object

Fails if obj is nil.



713
714
715
716
# File 'lib/minitest/assertions.rb', line 713

def refute_nil obj, msg = nil
  msg = message(msg) { "Expected #{mu_pp obj} to not be nil" }
  refute obj.nil?, msg
end

#refute_operator(o1, op, o2 = UNDEFINED, msg = nil) ⇒ Object

Fails if o1 is not op o2. Eg:

refute_operator 1, :>, 2 #=> pass
refute_operator 1, :<, 2 #=> fail


745
746
747
748
749
750
# File 'lib/minitest/assertions.rb', line 745

def refute_operator o1, op, o2 = UNDEFINED, msg = nil
  return refute_predicate o1, op, msg if UNDEFINED == o2
  assert_respond_to o1, op
  msg = message(msg) { "Expected #{mu_pp o1} to not be #{op} #{mu_pp o2}" }
  refute o1.__send__(op, o2), msg
end

#refute_path_exists(path, msg = nil) ⇒ Object

Fails if path exists.



755
756
757
758
# File 'lib/minitest/assertions.rb', line 755

def refute_path_exists path, msg = nil
  msg = message(msg) { "Expected path '#{path}' to not exist" }
  refute File.exist?(path), msg
end

#refute_patternObject

For testing with pattern matching (only supported with Ruby 3.0 and later)

# pass
refute_pattern { [1,2,3] => [String] }

# fail "NoMatchingPatternError expected, but nothing was raised."
refute_pattern { [1,2,3] => [Integer, Integer, Integer] }

This assertion expects a NoMatchingPatternError exception, and will fail if none is raised. Any other exceptions will be raised as normal and generate a test error.



730
731
732
733
734
735
736
737
# File 'lib/minitest/assertions.rb', line 730

def refute_pattern
  flunk "refute_pattern requires a block to capture errors." unless block_given?

  yield
  flunk "NoMatchingPatternError expected, but nothing was raised."
rescue NoMatchingPatternError
  pass
end

#refute_predicate(o1, op, msg = nil) ⇒ Object

For testing with predicates.

refute_predicate str, :empty?

This is really meant for specs and is front-ended by refute_operator:

str.wont_be :empty?


769
770
771
772
773
# File 'lib/minitest/assertions.rb', line 769

def refute_predicate o1, op, msg = nil
  assert_respond_to o1, op, include_all:true
  msg = message(msg) { "Expected #{mu_pp o1} to not be #{op}" }
  refute o1.__send__(op), msg
end

#refute_respond_to(obj, meth, msg = nil, include_all: false) ⇒ Object

Fails if obj responds to the message meth. include_all defaults to false to match Object#respond_to?



779
780
781
782
783
# File 'lib/minitest/assertions.rb', line 779

def refute_respond_to obj, meth, msg = nil, include_all: false
  msg = message(msg) { "Expected #{mu_pp obj} to not respond to #{meth}" }

  refute obj.respond_to?(meth, include_all), msg
end

#refute_same(exp, act, msg = nil) ⇒ Object

Fails if exp is the same (by object identity) as act.



788
789
790
791
792
793
794
# File 'lib/minitest/assertions.rb', line 788

def refute_same exp, act, msg = nil
  msg = message(msg) {
    data = [mu_pp(act), act.object_id, mu_pp(exp), exp.object_id]
    "Expected %s (oid=%d) to not be the same as %s (oid=%d)" % data
  }
  refute exp.equal?(act), msg
end

#skip(msg = nil, _ignored = nil) ⇒ Object

Skips the current run. If run in verbose-mode, the skipped run gets listed at the end of the run but doesn’t cause a failure exit code.

Raises:



801
802
803
804
805
# File 'lib/minitest/assertions.rb', line 801

def skip msg = nil, _ignored = nil
  msg ||= "Skipped, no message given"
  @skip = true
  raise Minitest::Skip, msg
end

#skip_until(y, m, d, msg) ⇒ Object

Skips the current run until a given date (in the local time zone). This allows you to put some fixes on hold until a later date, but still holds you accountable and prevents you from forgetting it.



813
814
815
816
817
# File 'lib/minitest/assertions.rb', line 813

def skip_until y, m, d, msg
  skip msg if Time.now < Time.local(y, m, d)
  where = caller(1..1).first.rpartition(":in").reject(&:empty?).first
  warn "Stale skip_until %p at %s" % [msg, where]
end

#skipped?Boolean

Was this testcase skipped? Meant for #teardown.

Returns:

  • (Boolean)


822
823
824
# File 'lib/minitest/assertions.rb', line 822

def skipped?
  defined?(@skip) and @skip
end

#things_to_diff(exp, act) ⇒ Object

Returns things to diff [expect, butwas], or [nil, nil] if nothing to diff.

Criterion:

  1. Strings include newlines or escaped newlines, but not both.

  2. or: String lengths are > 30 characters.

  3. or: Strings are equal to each other (but maybe different encodings?).

  4. and: we found a diff executable.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/minitest/assertions.rb', line 102

def things_to_diff exp, act
  expect = mu_pp_for_diff exp
  butwas = mu_pp_for_diff act

  e1, e2 = expect.include?("\n"), expect.include?("\\n")
  b1, b2 = butwas.include?("\n"), butwas.include?("\\n")

  need_to_diff =
    (e1 ^ e2                  ||
     b1 ^ b2                  ||
     expect.size > 30         ||
     butwas.size > 30         ||
     expect == butwas)        &&
    Minitest::Assertions.diff

  need_to_diff && [expect, butwas]
end