Module: Minitest::Reportable
Overview
Shared code for anything that can get passed to a Reporter. See Minitest::Test & Minitest::Result.
Constant Summary collapse
- BASE_DIR =
:nodoc:
"#{Dir.pwd}/"
Instance Method Summary collapse
-
#class_name ⇒ Object
:nodoc:.
-
#error? ⇒ Boolean
Did this run error?.
-
#location ⇒ Object
The location identifier of this test.
-
#passed? ⇒ Boolean
Did this run pass?.
-
#result_code ⇒ Object
Returns “.”, “F”, or “E” based on the result of the run.
-
#skipped? ⇒ Boolean
Was this run skipped?.
Instance Method Details
#class_name ⇒ Object
:nodoc:
556 557 558 |
# File 'lib/minitest.rb', line 556 def class_name # :nodoc: raise NotImplementedError, "subclass responsibility" end |
#error? ⇒ Boolean
Did this run error?
577 578 579 |
# File 'lib/minitest.rb', line 577 def error? self.failures.any? { |f| UnexpectedError === f } end |
#location ⇒ Object
The location identifier of this test. Depends on a method existing called class_name.
551 552 553 554 |
# File 'lib/minitest.rb', line 551 def location loc = " [#{self.failure.location.delete_prefix BASE_DIR}]" unless passed? or error? "#{self.class_name}##{self.name}#{loc}" end |
#passed? ⇒ Boolean
Did this run pass?
Note: skipped runs are not considered passing, but they don’t cause the process to exit non-zero.
541 542 543 |
# File 'lib/minitest.rb', line 541 def passed? not self.failure end |
#result_code ⇒ Object
Returns “.”, “F”, or “E” based on the result of the run.
563 564 565 |
# File 'lib/minitest.rb', line 563 def result_code self.failure and self.failure.result_code or "." end |
#skipped? ⇒ Boolean
Was this run skipped?
570 571 572 |
# File 'lib/minitest.rb', line 570 def skipped? self.failure and Skip === self.failure end |