Module: Minitest::Spec::DSL
- Included in:
- BenchSpec, Minitest::Spec
- Defined in:
- lib/minitest/spec.rb
Overview
Oh look! A Minitest::Spec::DSL module! Eat your heart out DHH.
Defined Under Namespace
Modules: InstanceMethods
Constant Summary collapse
- TYPES =
Contains pairs of matchers and Spec classes to be used to calculate the superclass of a top-level describe. This allows for automatically customizable spec types.
See: register_spec_type and spec_type
[[//, Minitest::Spec]]
Instance Attribute Summary collapse
-
#desc ⇒ Object
readonly
:nodoc:.
Class Method Summary collapse
-
.extended(obj) ⇒ Object
:nodoc:.
Instance Method Summary collapse
-
#after(_type = nil, &block) ⇒ Object
Define an 'after' action.
-
#before(_type = nil, &block) ⇒ Object
Define a 'before' action.
-
#children ⇒ Object
:nodoc:.
-
#create(name, desc) ⇒ Object
:nodoc:.
-
#describe_stack ⇒ Object
:nodoc:.
-
#it(desc = "anonymous", &block) ⇒ Object
(also: #specify)
Define an expectation with name
desc. -
#let(name, &block) ⇒ Object
Essentially, define an accessor for
namewithblock. -
#name ⇒ Object
:nodoc:.
-
#nuke_test_methods! ⇒ Object
:nodoc:.
-
#register_spec_type(*args, &block) ⇒ Object
Register a new type of spec that matches the spec's description.
-
#spec_type(desc, *additional) ⇒ Object
Figure out the spec class to use based on a spec's description.
-
#subject(&block) ⇒ Object
Another lazy man's accessor generator.
-
#to_s ⇒ Object
:nodoc:.
Instance Attribute Details
#desc ⇒ Object (readonly)
:nodoc:
285 286 287 |
# File 'lib/minitest/spec.rb', line 285 def desc @desc end |
Class Method Details
.extended(obj) ⇒ Object
:nodoc:
329 330 331 |
# File 'lib/minitest/spec.rb', line 329 def self.extended obj # :nodoc: obj.send :include, InstanceMethods end |
Instance Method Details
#after(_type = nil, &block) ⇒ Object
Define an 'after' action. Inherits the way normal methods should.
NOTE: type is ignored and is only there to make porting easier.
Equivalent to Minitest::Test#teardown.
199 200 201 202 203 204 |
# File 'lib/minitest/spec.rb', line 199 def after _type = nil, &block define_method :teardown do self.instance_eval(&block) super() end end |
#before(_type = nil, &block) ⇒ Object
Define a 'before' action. Inherits the way normal methods should.
NOTE: type is ignored and is only there to make porting easier.
Equivalent to Minitest::Test#setup.
185 186 187 188 189 190 |
# File 'lib/minitest/spec.rb', line 185 def before _type = nil, &block define_method :setup do super() self.instance_eval(&block) end end |
#children ⇒ Object
:nodoc:
168 169 170 |
# File 'lib/minitest/spec.rb', line 168 def children # :nodoc: @children ||= [] end |
#create(name, desc) ⇒ Object
:nodoc:
264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/minitest/spec.rb', line 264 def create name, desc # :nodoc: cls = Class.new(self) do @name = name @desc = desc nuke_test_methods! end children << cls cls end |
#describe_stack ⇒ Object
:nodoc:
164 165 166 |
# File 'lib/minitest/spec.rb', line 164 def describe_stack # :nodoc: Thread.current[:describe_stack] ||= [] end |
#it(desc = "anonymous", &block) ⇒ Object Also known as: specify
Define an expectation with name desc. Name gets morphed to a proper test method name. For some freakish reason, people who write specs don't like class inheritance, so this goes way out of its way to make sure that expectations aren't inherited.
This is also aliased to #specify and doesn't require a desc arg.
Hint: If you do want inheritance, use minitest/test. You can mix and match between assertions and expectations as much as you want.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/minitest/spec.rb', line 217 def it desc = "anonymous", &block block ||= proc { skip "(no tests defined)" } @specs ||= 0 @specs += 1 name = "test_%04d_%s" % [ @specs, desc ] undef_klasses = self.children.reject { |c| c.public_method_defined? name } define_method name, &block undef_klasses.each do |undef_klass| undef_klass.send :undef_method, name end name end |
#let(name, &block) ⇒ Object
Essentially, define an accessor for name with block.
Why use let instead of def? I honestly don't know.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/minitest/spec.rb', line 241 def let name, &block name = name.to_s pre, post = "let '#{name}' cannot ", ". Please use another name." methods = Minitest::Spec.instance_methods.map(&:to_s) - %w[subject] raise ArgumentError, "#{pre}begin with 'test'#{post}" if name =~ /\Atest/ raise ArgumentError, "#{pre}override a method in Minitest::Spec#{post}" if methods.include? name define_method name do @_memoized ||= {} @_memoized.fetch(name) { |k| @_memoized[k] = instance_eval(&block) } end end |
#name ⇒ Object
:nodoc:
277 278 279 |
# File 'lib/minitest/spec.rb', line 277 def name # :nodoc: defined?(@name) ? @name : super end |
#nuke_test_methods! ⇒ Object
:nodoc:
172 173 174 175 176 |
# File 'lib/minitest/spec.rb', line 172 def nuke_test_methods! # :nodoc: self.public_instance_methods.grep(/^test_/).each do |name| self.send :undef_method, name end end |
#register_spec_type(*args, &block) ⇒ Object
Register a new type of spec that matches the spec's description. This method can take either a Regexp and a spec class or a spec class and a block that takes the description and returns true if it matches.
Eg:
register_spec_type(/Controller$/, Minitest::Spec::Rails)
or:
register_spec_type(Minitest::Spec::RailsModel) do |desc|
desc.superclass == ActiveRecord::Base
end
140 141 142 143 144 145 146 147 |
# File 'lib/minitest/spec.rb', line 140 def register_spec_type *args, &block if block then matcher, klass = block, args.first else matcher, klass = *args end TYPES.unshift [matcher, klass] end |
#spec_type(desc, *additional) ⇒ Object
Figure out the spec class to use based on a spec's description. Eg:
spec_type("BlahController") # => Minitest::Spec::Rails
154 155 156 157 158 159 160 161 162 |
# File 'lib/minitest/spec.rb', line 154 def spec_type desc, *additional TYPES.find { |matcher, _klass| if matcher.respond_to? :call then matcher.call desc, *additional else matcher === desc.to_s end }.last end |
#subject(&block) ⇒ Object
Another lazy man's accessor generator. Made even more lazy by setting the name for you to subject.
260 261 262 |
# File 'lib/minitest/spec.rb', line 260 def subject &block let :subject, &block end |
#to_s ⇒ Object
:nodoc:
281 282 283 |
# File 'lib/minitest/spec.rb', line 281 def to_s # :nodoc: name # Can't alias due to 1.8.7, not sure why end |