Class: Minitest::SummaryReporter
- Inherits:
-
StatisticsReporter
- Object
- AbstractReporter
- Reporter
- StatisticsReporter
- Minitest::SummaryReporter
- Defined in:
- lib/minitest.rb
Overview
A reporter that prints the header, summary, and failure details at the end of the run.
This is added to the top-level CompositeReporter at the start of the run. If you want to change the output of minitest via a plugin, pull this out of the composite and replace it with your own.
Instance Attribute Summary collapse
-
#old_sync ⇒ Object
Returns the value of attribute old_sync.
-
#sync ⇒ Object
:stopdoc:.
Attributes inherited from StatisticsReporter
#assertions, #count, #errors, #failures, #results, #skips, #start_time, #total_time
Attributes inherited from Reporter
Instance Method Summary collapse
-
#aggregated_results(io) ⇒ Object
:nodoc:.
-
#report ⇒ Object
:nodoc:.
-
#start ⇒ Object
:startdoc:.
-
#statistics ⇒ Object
:nodoc:.
-
#summary ⇒ Object
:nodoc:.
-
#to_s ⇒ Object
:nodoc:.
Methods inherited from StatisticsReporter
#initialize, #passed?, #record
Methods inherited from Reporter
Methods inherited from AbstractReporter
Constructor Details
This class inherits a constructor from Minitest::StatisticsReporter
Instance Attribute Details
#old_sync ⇒ Object
Returns the value of attribute old_sync.
791 792 793 |
# File 'lib/minitest.rb', line 791 def old_sync @old_sync end |
Instance Method Details
#aggregated_results(io) ⇒ Object
:nodoc:
823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 |
# File 'lib/minitest.rb', line 823 def aggregated_results io # :nodoc: filtered_results = results.dup filtered_results.reject!(&:skipped?) unless [:verbose] or [:show_skips] skip = [:skip] || [] filtered_results.each_with_index { |result, i| next if skip.include? result.result_code io.puts "\n%3d) %s" % [i+1, result] } io.puts io end |
#report ⇒ Object
:nodoc:
806 807 808 809 810 811 812 813 814 815 816 |
# File 'lib/minitest.rb', line 806 def report # :nodoc: super io.sync = self.old_sync io.puts unless [:verbose] # finish the dots io.puts io.puts statistics aggregated_results io io.puts summary end |
#start ⇒ Object
:startdoc:
794 795 796 797 798 799 800 801 802 803 804 |
# File 'lib/minitest.rb', line 794 def start # :nodoc: super io.puts "Run options: #{[:args]}" io.puts io.puts "# Running:" io.puts self.sync = io.respond_to? :"sync=" # stupid emacs self.old_sync, io.sync = io.sync, true if self.sync end |
#statistics ⇒ Object
:nodoc:
818 819 820 821 |
# File 'lib/minitest.rb', line 818 def statistics # :nodoc: "Finished in %.6fs, %.4f runs/s, %.4f assertions/s." % [total_time, count / total_time, assertions / total_time] end |
#summary ⇒ Object
:nodoc:
843 844 845 846 847 848 849 850 851 852 |
# File 'lib/minitest.rb', line 843 def summary # :nodoc: extra = "" extra = "\n\nYou have skipped tests. Run with --verbose for details." if results.any?(&:skipped?) unless [:verbose] or [:show_skips] or ENV["MT_NO_SKIP_MSG"] "%d runs, %d assertions, %d failures, %d errors, %d skips%s" % [count, assertions, failures, errors, skips, extra] end |
#to_s ⇒ Object
:nodoc:
839 840 841 |
# File 'lib/minitest.rb', line 839 def to_s # :nodoc: aggregated_results(StringIO.new(''.b)).string end |