Class: Minitest::AbstractReporter

Inherits:
Object
  • Object
show all
Defined in:
lib/minitest.rb

Overview

Defines the API for Reporters. Subclass this and override whatever you want. Go nuts.

Direct Known Subclasses

CompositeReporter, Reporter

Instance Method Summary collapse

Constructor Details

#initializeAbstractReporter

:nodoc:



642
643
644
# File 'lib/minitest.rb', line 642

def initialize # :nodoc:
  @mutex = Mutex.new
end

Instance Method Details

#passed?Boolean

Did this run pass?

Returns:

  • (Boolean)


677
678
679
# File 'lib/minitest.rb', line 677

def passed?
  true
end

#prerecord(klass, name) ⇒ Object

About to start running a test. This allows a reporter to show that it is starting or that we are in the middle of a test run.



656
657
# File 'lib/minitest.rb', line 656

def prerecord klass, name
end

#record(result) ⇒ Object

Output and record the result of the test. Call result#result_code to get the result character string. Stores the result of the run if the run did not pass.



665
666
# File 'lib/minitest.rb', line 665

def record result
end

#reportObject

Outputs the summary of the run.



671
672
# File 'lib/minitest.rb', line 671

def report
end

#startObject

Starts reporting on the run.



649
650
# File 'lib/minitest.rb', line 649

def start
end

#synchronize(&block) ⇒ Object

:nodoc:



681
682
683
# File 'lib/minitest.rb', line 681

def synchronize(&block) # :nodoc:
  @mutex.synchronize(&block)
end