Class: Minitest::AbstractReporter
Overview
Defines the API for Reporters. Subclass this and override whatever you want. Go nuts.
Direct Known Subclasses
Instance Method Summary collapse
-
#initialize ⇒ AbstractReporter
constructor
:nodoc:.
-
#passed? ⇒ Boolean
Did this run pass?.
-
#prerecord(klass, name) ⇒ Object
About to start running a test.
-
#record(result) ⇒ Object
Output and record the result of the test.
-
#report ⇒ Object
Outputs the summary of the run.
-
#start ⇒ Object
Starts reporting on the run.
-
#synchronize(&block) ⇒ Object
:nodoc:.
Constructor Details
#initialize ⇒ AbstractReporter
:nodoc:
641 642 643 |
# File 'lib/minitest.rb', line 641 def initialize # :nodoc: @mutex = Mutex.new end |
Instance Method Details
#passed? ⇒ Boolean
Did this run pass?
676 677 678 |
# File 'lib/minitest.rb', line 676 def passed? true end |
#prerecord(klass, name) ⇒ Object
About to start running a test. This allows a reporter to show that it is starting or that we are in the middle of a test run.
655 656 |
# File 'lib/minitest.rb', line 655 def prerecord klass, name end |
#record(result) ⇒ Object
Output and record the result of the test. Call result#result_code to get the result character string. Stores the result of the run if the run did not pass.
664 665 |
# File 'lib/minitest.rb', line 664 def record result end |
#report ⇒ Object
Outputs the summary of the run.
670 671 |
# File 'lib/minitest.rb', line 670 def report end |
#start ⇒ Object
Starts reporting on the run.
648 649 |
# File 'lib/minitest.rb', line 648 def start end |
#synchronize(&block) ⇒ Object
:nodoc:
680 681 682 |
# File 'lib/minitest.rb', line 680 def synchronize(&block) # :nodoc: @mutex.synchronize(&block) end |