Class: Minitest::AbstractReporter
- Includes:
- Mutex_m
- Defined in:
- lib/minitest.rb
Overview
Defines the API for Reporters. Subclass this and override whatever you want. Go nuts.
Direct Known Subclasses
Instance Method Summary collapse
-
#passed? ⇒ Boolean
Did this run pass?.
-
#prerecord(klass, name) ⇒ Object
About to start running a test.
-
#record(result) ⇒ Object
Output and record the result of the test.
-
#report ⇒ Object
Outputs the summary of the run.
-
#start ⇒ Object
Starts reporting on the run.
Instance Method Details
#passed? ⇒ Boolean
Did this run pass?
626 627 628 |
# File 'lib/minitest.rb', line 626 def passed? true end |
#prerecord(klass, name) ⇒ Object
About to start running a test. This allows a reporter to show that it is starting or that we are in the middle of a test run.
605 606 |
# File 'lib/minitest.rb', line 605 def prerecord klass, name end |
#record(result) ⇒ Object
Output and record the result of the test. Call result#result_code to get the result character string. Stores the result of the run if the run did not pass.
614 615 |
# File 'lib/minitest.rb', line 614 def record result end |
#report ⇒ Object
Outputs the summary of the run.
620 621 |
# File 'lib/minitest.rb', line 620 def report end |
#start ⇒ Object
Starts reporting on the run.
598 599 |
# File 'lib/minitest.rb', line 598 def start end |