Class: Minitest::AbstractReporter
Overview
Defines the API for Reporters. Subclass this and override whatever you want. Go nuts.
Direct Known Subclasses
Instance Method Summary collapse
-
#initialize ⇒ AbstractReporter
constructor
:nodoc:.
-
#passed? ⇒ Boolean
Did this run pass?.
-
#prerecord(klass, name) ⇒ Object
About to start running a test.
-
#record(result) ⇒ Object
Output and record the result of the test.
-
#report ⇒ Object
Outputs the summary of the run.
-
#start ⇒ Object
Starts reporting on the run.
-
#synchronize(&block) ⇒ Object
:nodoc:.
Constructor Details
#initialize ⇒ AbstractReporter
:nodoc:
629 630 631 |
# File 'lib/minitest.rb', line 629 def initialize # :nodoc: @mutex = Mutex.new end |
Instance Method Details
#passed? ⇒ Boolean
Did this run pass?
664 665 666 |
# File 'lib/minitest.rb', line 664 def passed? true end |
#prerecord(klass, name) ⇒ Object
About to start running a test. This allows a reporter to show that it is starting or that we are in the middle of a test run.
643 644 |
# File 'lib/minitest.rb', line 643 def prerecord klass, name end |
#record(result) ⇒ Object
Output and record the result of the test. Call result#result_code to get the result character string. Stores the result of the run if the run did not pass.
652 653 |
# File 'lib/minitest.rb', line 652 def record result end |
#report ⇒ Object
Outputs the summary of the run.
658 659 |
# File 'lib/minitest.rb', line 658 def report end |
#start ⇒ Object
Starts reporting on the run.
636 637 |
# File 'lib/minitest.rb', line 636 def start end |
#synchronize(&block) ⇒ Object
:nodoc:
668 669 670 |
# File 'lib/minitest.rb', line 668 def synchronize(&block) # :nodoc: @mutex.synchronize(&block) end |