Method: Minitest::AbstractReporter#prerecord
- Defined in:
- lib/minitest.rb
#prerecord(klass, name) ⇒ Object
About to start running a test. This allows a reporter to show that it is starting or that we are in the middle of a test run.
591 592 |
# File 'lib/minitest.rb', line 591 def prerecord klass, name end |