Module: Minitest::Guard
Overview
Provides a simple set of guards that you can use in your tests to skip execution if it is not applicable. These methods are mixed into Test as both instance and class methods so you can use them inside or outside of the test methods.
def test_something_for_mri
skip "bug 1234" if jruby?
# ...
end
if windows? then
# ... lots of test methods ...
end
Instance Method Summary collapse
-
#jruby?(platform = RUBY_PLATFORM) ⇒ Boolean
Is this running on jruby?.
-
#maglev?(platform = defined?(RUBY_ENGINE) && RUBY_ENGINE) ⇒ Boolean
Is this running on maglev?.
-
#mri?(platform = RUBY_DESCRIPTION) ⇒ Boolean
Is this running on mri?.
-
#osx?(platform = RUBY_PLATFORM) ⇒ Boolean
Is this running on macOS?.
-
#rubinius?(platform = defined?(RUBY_ENGINE) && RUBY_ENGINE) ⇒ Boolean
Is this running on rubinius?.
-
#windows?(platform = RUBY_PLATFORM) ⇒ Boolean
Is this running on windows?.
Instance Method Details
#jruby?(platform = RUBY_PLATFORM) ⇒ Boolean
Is this running on jruby?
990 991 992 |
# File 'lib/minitest.rb', line 990 def jruby? platform = RUBY_PLATFORM "java" == platform end |
#maglev?(platform = defined?(RUBY_ENGINE) && RUBY_ENGINE) ⇒ Boolean
Is this running on maglev?
997 998 999 1000 1001 1002 |
# File 'lib/minitest.rb', line 997 def maglev? platform = defined?(RUBY_ENGINE) && RUBY_ENGINE where = Minitest.filter_backtrace(caller).first where = where.split(/:in /, 2).first # clean up noise warn "DEPRECATED: `maglev?` called from #{where}. This will fail in Minitest 6." "maglev" == platform end |
#mri?(platform = RUBY_DESCRIPTION) ⇒ Boolean
Is this running on mri?
1007 1008 1009 |
# File 'lib/minitest.rb', line 1007 def mri? platform = RUBY_DESCRIPTION /^ruby/ =~ platform end |
#osx?(platform = RUBY_PLATFORM) ⇒ Boolean
Is this running on macOS?
1014 1015 1016 |
# File 'lib/minitest.rb', line 1014 def osx? platform = RUBY_PLATFORM /darwin/ =~ platform end |
#rubinius?(platform = defined?(RUBY_ENGINE) && RUBY_ENGINE) ⇒ Boolean
Is this running on rubinius?
1021 1022 1023 1024 1025 1026 |
# File 'lib/minitest.rb', line 1021 def rubinius? platform = defined?(RUBY_ENGINE) && RUBY_ENGINE where = Minitest.filter_backtrace(caller).first where = where.split(/:in /, 2).first # clean up noise warn "DEPRECATED: `rubinius?` called from #{where}. This will fail in Minitest 6." "rbx" == platform end |
#windows?(platform = RUBY_PLATFORM) ⇒ Boolean
Is this running on windows?
1031 1032 1033 |
# File 'lib/minitest.rb', line 1031 def windows? platform = RUBY_PLATFORM /mswin|mingw/ =~ platform end |