Module: Minitest::Guard
Overview
Provides a simple set of guards that you can use in your tests to skip execution if it is not applicable. These methods are mixed into Test as both instance and class methods so you can use them inside or outside of the test methods.
def test_something_for_mri
skip "bug 1234" if jruby?
# ...
end
if windows? then
# ... lots of test methods ...
end
Instance Method Summary collapse
-
#jruby?(platform = RUBY_PLATFORM) ⇒ Boolean
Is this running on jruby?.
-
#maglev?(platform = defined?(RUBY_ENGINE) && RUBY_ENGINE) ⇒ Boolean
Is this running on maglev?.
-
#mri?(platform = RUBY_DESCRIPTION) ⇒ Boolean
Is this running on mri?.
-
#osx?(platform = RUBY_PLATFORM) ⇒ Boolean
Is this running on macOS?.
-
#rubinius?(platform = defined?(RUBY_ENGINE) && RUBY_ENGINE) ⇒ Boolean
Is this running on rubinius?.
-
#windows?(platform = RUBY_PLATFORM) ⇒ Boolean
Is this running on windows?.
Instance Method Details
#jruby?(platform = RUBY_PLATFORM) ⇒ Boolean
Is this running on jruby?
1057 1058 1059 |
# File 'lib/minitest.rb', line 1057 def jruby? platform = RUBY_PLATFORM "java" == platform end |
#maglev?(platform = defined?(RUBY_ENGINE) && RUBY_ENGINE) ⇒ Boolean
Is this running on maglev?
1064 1065 1066 1067 1068 1069 |
# File 'lib/minitest.rb', line 1064 def maglev? platform = defined?(RUBY_ENGINE) && RUBY_ENGINE where = Minitest.filter_backtrace(caller).first where = where.split(/:in /, 2).first # clean up noise warn "DEPRECATED: `maglev?` called from #{where}. This will fail in Minitest 6." "maglev" == platform end |
#mri?(platform = RUBY_DESCRIPTION) ⇒ Boolean
Is this running on mri?
1074 1075 1076 |
# File 'lib/minitest.rb', line 1074 def mri? platform = RUBY_DESCRIPTION /^ruby/ =~ platform end |
#osx?(platform = RUBY_PLATFORM) ⇒ Boolean
Is this running on macOS?
1081 1082 1083 |
# File 'lib/minitest.rb', line 1081 def osx? platform = RUBY_PLATFORM /darwin/ =~ platform end |
#rubinius?(platform = defined?(RUBY_ENGINE) && RUBY_ENGINE) ⇒ Boolean
Is this running on rubinius?
1088 1089 1090 1091 1092 1093 |
# File 'lib/minitest.rb', line 1088 def rubinius? platform = defined?(RUBY_ENGINE) && RUBY_ENGINE where = Minitest.filter_backtrace(caller).first where = where.split(/:in /, 2).first # clean up noise warn "DEPRECATED: `rubinius?` called from #{where}. This will fail in Minitest 6." "rbx" == platform end |
#windows?(platform = RUBY_PLATFORM) ⇒ Boolean
Is this running on windows?
1098 1099 1100 |
# File 'lib/minitest.rb', line 1098 def windows? platform = RUBY_PLATFORM /mswin|mingw/ =~ platform end |