Module: Minitest::Reportable
Overview
Shared code for anything that can get passed to a Reporter. See Minitest::Test & Minitest::Result.
Constant Summary collapse
- BASE_DIR =
:nodoc:
"#{Dir.pwd}/"
Instance Method Summary collapse
-
#class_name ⇒ Object
:nodoc:.
-
#error? ⇒ Boolean
Did this run error?.
-
#location ⇒ Object
The location identifier of this test.
-
#passed? ⇒ Boolean
Did this run pass?.
-
#result_code ⇒ Object
Returns “.”, “F”, or “E” based on the result of the run.
-
#skipped? ⇒ Boolean
Was this run skipped?.
Instance Method Details
#class_name ⇒ Object
:nodoc:
543 544 545 |
# File 'lib/minitest.rb', line 543 def class_name # :nodoc: raise NotImplementedError, "subclass responsibility" end |
#error? ⇒ Boolean
Did this run error?
564 565 566 |
# File 'lib/minitest.rb', line 564 def error? self.failures.any? { |f| UnexpectedError === f } end |
#location ⇒ Object
The location identifier of this test. Depends on a method existing called class_name.
538 539 540 541 |
# File 'lib/minitest.rb', line 538 def location loc = " [#{self.failure.location.delete_prefix BASE_DIR}]" unless passed? or error? "#{self.class_name}##{self.name}#{loc}" end |
#passed? ⇒ Boolean
Did this run pass?
Note: skipped runs are not considered passing, but they don’t cause the process to exit non-zero.
528 529 530 |
# File 'lib/minitest.rb', line 528 def passed? not self.failure end |
#result_code ⇒ Object
Returns “.”, “F”, or “E” based on the result of the run.
550 551 552 |
# File 'lib/minitest.rb', line 550 def result_code self.failure and self.failure.result_code or "." end |
#skipped? ⇒ Boolean
Was this run skipped?
557 558 559 |
# File 'lib/minitest.rb', line 557 def skipped? self.failure and Skip === self.failure end |