Class: Minitest::Runnable

Inherits:
Object show all
Defined in:
lib/minitest.rb,
lib/minitest.rb

Overview

re-open

Direct Known Subclasses

Result, Test

Constant Summary collapse

SIGNALS =

:nodoc:

Signal.list
@@marshal_dump_warned =
false

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(name) ⇒ Runnable

:nodoc:



465
466
467
468
469
470
# File 'lib/minitest.rb', line 465

def initialize name # :nodoc:
  self.name       = name
  self.failures   = []
  self.assertions = 0
  # lazy initializer for metadata
end

Instance Attribute Details

#assertionsObject

Number of assertions executed in this run.



311
312
313
# File 'lib/minitest.rb', line 311

def assertions
  @assertions
end

#failuresObject

An assertion raised during the run, if any.



316
317
318
# File 'lib/minitest.rb', line 316

def failures
  @failures
end

#metadataObject

Metadata you attach to the test results that get sent to the reporter.

Lazily initializes to a hash, to keep memory down.

NOTE: this data must be plain (read: marshal-able) data! Hashes! Arrays! Strings!



480
481
482
# File 'lib/minitest.rb', line 480

def 
  @metadata ||= {}
end

#timeObject

The time it took to run.



321
322
323
# File 'lib/minitest.rb', line 321

def time
  @time
end

Class Method Details

.inherited(klass) ⇒ Object

:nodoc:



1158
1159
1160
1161
# File 'lib/minitest.rb', line 1158

def self.inherited klass # :nodoc:
  self.runnables << klass
  super
end

.methods_matching(re) ⇒ Object

Returns all instance methods matching the pattern re.



348
349
350
# File 'lib/minitest.rb', line 348

def self.methods_matching re
  public_instance_methods(true).grep(re).map(&:to_s)
end

.on_signal(name, action) ⇒ Object

:nodoc:



417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/minitest.rb', line 417

def self.on_signal name, action # :nodoc:
  supported = SIGNALS[name]

  old_trap = trap name do
    old_trap.call if old_trap.respond_to? :call
    action.call
  end if supported

  yield
ensure
  trap name, old_trap if supported
end

.resetObject

:nodoc:



352
353
354
# File 'lib/minitest.rb', line 352

def self.reset # :nodoc:
  @@runnables = []
end

.run(reporter, options = {}) ⇒ Object

Responsible for running all runnable methods in a given class, each in its own instance. Each instance is passed to the reporter to record.



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/minitest.rb', line 363

def self.run reporter, options = {}
  pos = options[:filter]
  neg = options[:exclude]

  pos = Regexp.new $1 if pos.is_a?(String) && pos =~ %r%/(.*)/%
  neg = Regexp.new $1 if neg.is_a?(String) && neg =~ %r%/(.*)/%

  filtered_methods = self.runnable_methods
    .select { |m| !pos ||  pos === m || pos === "#{self}##{m}"  }
    .reject { |m|  neg && (neg === m || neg === "#{self}##{m}") }

  return if filtered_methods.empty?

  with_info_handler reporter do
    filtered_methods.each do |method_name|
      run_one_method self, method_name, reporter
    end
  end
end

.run_one_method(klass, method_name, reporter) ⇒ Object

Runs a single method and has the reporter record the result. This was considered internal API but is factored out of run so that subclasses can specialize the running of an individual test. See Minitest::ParallelTest::ClassMethods for an example.



389
390
391
392
# File 'lib/minitest.rb', line 389

def self.run_one_method klass, method_name, reporter
  reporter.prerecord klass, method_name
  reporter.record Minitest.run_one_method(klass, method_name)
end

.runnable_methodsObject

Each subclass of Runnable is responsible for overriding this method to return all runnable methods. See #methods_matching.

Raises:

  • (NotImplementedError)


434
435
436
# File 'lib/minitest.rb', line 434

def self.runnable_methods
  raise NotImplementedError, "subclass responsibility"
end

.runnablesObject

Returns all subclasses of Runnable.



441
442
443
# File 'lib/minitest.rb', line 441

def self.runnables
  @@runnables
end

.test_orderObject

Defines the order to run tests (:random by default). Override this or use a convenience method to change it for your tests.



398
399
400
# File 'lib/minitest.rb', line 398

def self.test_order
  :random
end

.with_info_handler(reporter, &block) ⇒ Object

:nodoc:



402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/minitest.rb', line 402

def self.with_info_handler reporter, &block # :nodoc:
  handler = lambda do
    unless reporter.passed? then
      warn "Current results:"
      warn ""
      warn reporter.reporters.first
      warn ""
    end
  end

  on_signal ::Minitest.info_signal, handler, &block
end

Instance Method Details

#failureObject

:nodoc:



461
462
463
# File 'lib/minitest.rb', line 461

def failure # :nodoc:
  self.failures.first
end

#marshal_dumpObject

:nodoc:



447
448
449
450
451
452
453
454
455
# File 'lib/minitest.rb', line 447

def marshal_dump # :nodoc:
  unless @@marshal_dump_warned then
    warn ["Minitest::Runnable#marshal_dump is deprecated.",
          "You might be violating internals. From", caller.first].join " "
    @@marshal_dump_warned = true
  end

  [self.name, self.failures, self.assertions, self.time]
end

#marshal_load(ary) ⇒ Object

:nodoc:



457
458
459
# File 'lib/minitest.rb', line 457

def marshal_load ary # :nodoc:
  self.name, self.failures, self.assertions, self.time = ary
end

#metadata?Boolean

Returns true if metadata exists.

Returns:

  • (Boolean)


492
493
494
# File 'lib/minitest.rb', line 492

def metadata?
  defined? @metadata
end

#nameObject

Name of the run.



334
335
336
# File 'lib/minitest.rb', line 334

def name
  @NAME
end

#name=(o) ⇒ Object

Set the name of the run.



341
342
343
# File 'lib/minitest.rb', line 341

def name= o
  @NAME = o
end

#passed?Boolean

Did this run pass?

Note: skipped runs are not considered passing, but they don’t cause the process to exit non-zero.

Returns:

  • (Boolean)

Raises:

  • (NotImplementedError)


509
510
511
# File 'lib/minitest.rb', line 509

def passed?
  raise NotImplementedError, "subclass responsibility"
end

#result_codeObject

Returns a single character string to print based on the result of the run. One of ".", "F", "E" or "S".

Raises:

  • (NotImplementedError)


518
519
520
# File 'lib/minitest.rb', line 518

def result_code
  raise NotImplementedError, "subclass responsibility"
end

#runObject

Runs a single method. Needs to return self.

Raises:

  • (NotImplementedError)


499
500
501
# File 'lib/minitest.rb', line 499

def run
  raise NotImplementedError, "subclass responsibility"
end

#skipped?Boolean

Was this run skipped? See #passed? for more information.

Returns:

  • (Boolean)

Raises:

  • (NotImplementedError)


525
526
527
# File 'lib/minitest.rb', line 525

def skipped?
  raise NotImplementedError, "subclass responsibility"
end

#time_itObject

:nodoc:



323
324
325
326
327
328
329
# File 'lib/minitest.rb', line 323

def time_it # :nodoc:
  t0 = Minitest.clock_time

  yield
ensure
  self.time = Minitest.clock_time - t0
end