Class: Minitest::Runnable

Inherits:
Object show all
Defined in:
lib/minitest.rb,
lib/minitest.rb

Overview

re-open

Direct Known Subclasses

Result, Test

Constant Summary collapse

SIGNALS =

:nodoc:

Signal.list
@@marshal_dump_warned =
false

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(name) ⇒ Runnable

:nodoc:



464
465
466
467
468
469
# File 'lib/minitest.rb', line 464

def initialize name # :nodoc:
  self.name       = name
  self.failures   = []
  self.assertions = 0
  # lazy initializer for metadata
end

Instance Attribute Details

#assertionsObject

Number of assertions executed in this run.



310
311
312
# File 'lib/minitest.rb', line 310

def assertions
  @assertions
end

#failuresObject

An assertion raised during the run, if any.



315
316
317
# File 'lib/minitest.rb', line 315

def failures
  @failures
end

#metadataObject

Metadata you attach to the test results that get sent to the reporter.

Lazily initializes to a hash, to keep memory down.

NOTE: this data must be plain (read: marshal-able) data! Hashes! Arrays! Strings!



479
480
481
# File 'lib/minitest.rb', line 479

def 
  @metadata ||= {}
end

#timeObject

The time it took to run.



320
321
322
# File 'lib/minitest.rb', line 320

def time
  @time
end

Class Method Details

.inherited(klass) ⇒ Object

:nodoc:



1157
1158
1159
1160
# File 'lib/minitest.rb', line 1157

def self.inherited klass # :nodoc:
  self.runnables << klass
  super
end

.methods_matching(re) ⇒ Object

Returns all instance methods matching the pattern re.



347
348
349
# File 'lib/minitest.rb', line 347

def self.methods_matching re
  public_instance_methods(true).grep(re).map(&:to_s)
end

.on_signal(name, action) ⇒ Object

:nodoc:



416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/minitest.rb', line 416

def self.on_signal name, action # :nodoc:
  supported = SIGNALS[name]

  old_trap = trap name do
    old_trap.call if old_trap.respond_to? :call
    action.call
  end if supported

  yield
ensure
  trap name, old_trap if supported
end

.resetObject

:nodoc:



351
352
353
# File 'lib/minitest.rb', line 351

def self.reset # :nodoc:
  @@runnables = []
end

.run(reporter, options = {}) ⇒ Object

Responsible for running all runnable methods in a given class, each in its own instance. Each instance is passed to the reporter to record.



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/minitest.rb', line 362

def self.run reporter, options = {}
  pos = options[:filter]
  neg = options[:exclude]

  pos = Regexp.new $1 if pos.is_a?(String) && pos =~ %r%/(.*)/%
  neg = Regexp.new $1 if neg.is_a?(String) && neg =~ %r%/(.*)/%

  filtered_methods = self.runnable_methods
    .select { |m| !pos ||  pos === m || pos === "#{self}##{m}"  }
    .reject { |m|  neg && (neg === m || neg === "#{self}##{m}") }

  return if filtered_methods.empty?

  with_info_handler reporter do
    filtered_methods.each do |method_name|
      run_one_method self, method_name, reporter
    end
  end
end

.run_one_method(klass, method_name, reporter) ⇒ Object

Runs a single method and has the reporter record the result. This was considered internal API but is factored out of run so that subclasses can specialize the running of an individual test. See Minitest::ParallelTest::ClassMethods for an example.



388
389
390
391
# File 'lib/minitest.rb', line 388

def self.run_one_method klass, method_name, reporter
  reporter.prerecord klass, method_name
  reporter.record Minitest.run_one_method(klass, method_name)
end

.runnable_methodsObject

Each subclass of Runnable is responsible for overriding this method to return all runnable methods. See #methods_matching.

Raises:

  • (NotImplementedError)


433
434
435
# File 'lib/minitest.rb', line 433

def self.runnable_methods
  raise NotImplementedError, "subclass responsibility"
end

.runnablesObject

Returns all subclasses of Runnable.



440
441
442
# File 'lib/minitest.rb', line 440

def self.runnables
  @@runnables
end

.test_orderObject

Defines the order to run tests (:random by default). Override this or use a convenience method to change it for your tests.



397
398
399
# File 'lib/minitest.rb', line 397

def self.test_order
  :random
end

.with_info_handler(reporter, &block) ⇒ Object

:nodoc:



401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/minitest.rb', line 401

def self.with_info_handler reporter, &block # :nodoc:
  handler = lambda do
    unless reporter.passed? then
      warn "Current results:"
      warn ""
      warn reporter.reporters.first
      warn ""
    end
  end

  on_signal ::Minitest.info_signal, handler, &block
end

Instance Method Details

#failureObject

:nodoc:



460
461
462
# File 'lib/minitest.rb', line 460

def failure # :nodoc:
  self.failures.first
end

#marshal_dumpObject

:nodoc:



446
447
448
449
450
451
452
453
454
# File 'lib/minitest.rb', line 446

def marshal_dump # :nodoc:
  unless @@marshal_dump_warned then
    warn ["Minitest::Runnable#marshal_dump is deprecated.",
          "You might be violating internals. From", caller.first].join " "
    @@marshal_dump_warned = true
  end

  [self.name, self.failures, self.assertions, self.time]
end

#marshal_load(ary) ⇒ Object

:nodoc:



456
457
458
# File 'lib/minitest.rb', line 456

def marshal_load ary # :nodoc:
  self.name, self.failures, self.assertions, self.time = ary
end

#metadata?Boolean

Returns true if metadata exists.

Returns:

  • (Boolean)


491
492
493
# File 'lib/minitest.rb', line 491

def metadata?
  defined? @metadata
end

#nameObject

Name of the run.



333
334
335
# File 'lib/minitest.rb', line 333

def name
  @NAME
end

#name=(o) ⇒ Object

Set the name of the run.



340
341
342
# File 'lib/minitest.rb', line 340

def name= o
  @NAME = o
end

#passed?Boolean

Did this run pass?

Note: skipped runs are not considered passing, but they don’t cause the process to exit non-zero.

Returns:

  • (Boolean)

Raises:

  • (NotImplementedError)


508
509
510
# File 'lib/minitest.rb', line 508

def passed?
  raise NotImplementedError, "subclass responsibility"
end

#result_codeObject

Returns a single character string to print based on the result of the run. One of ".", "F", "E" or "S".

Raises:

  • (NotImplementedError)


517
518
519
# File 'lib/minitest.rb', line 517

def result_code
  raise NotImplementedError, "subclass responsibility"
end

#runObject

Runs a single method. Needs to return self.

Raises:

  • (NotImplementedError)


498
499
500
# File 'lib/minitest.rb', line 498

def run
  raise NotImplementedError, "subclass responsibility"
end

#skipped?Boolean

Was this run skipped? See #passed? for more information.

Returns:

  • (Boolean)

Raises:

  • (NotImplementedError)


524
525
526
# File 'lib/minitest.rb', line 524

def skipped?
  raise NotImplementedError, "subclass responsibility"
end

#time_itObject

:nodoc:



322
323
324
325
326
327
328
# File 'lib/minitest.rb', line 322

def time_it # :nodoc:
  t0 = Minitest.clock_time

  yield
ensure
  self.time = Minitest.clock_time - t0
end