Class: Minitest::Runnable

Inherits:
Object show all
Defined in:
lib/minitest.rb,
lib/minitest.rb

Overview

re-open

Direct Known Subclasses

Result, Test

Constant Summary collapse

SIGNALS =

:nodoc:

Signal.list
@@marshal_dump_warned =
false

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(name) ⇒ Runnable

:nodoc:



445
446
447
448
449
# File 'lib/minitest.rb', line 445

def initialize name # :nodoc:
  self.name       = name
  self.failures   = []
  self.assertions = 0
end

Instance Attribute Details

#assertionsObject

Number of assertions executed in this run.



281
282
283
# File 'lib/minitest.rb', line 281

def assertions
  @assertions
end

#failuresObject

An assertion raised during the run, if any.



286
287
288
# File 'lib/minitest.rb', line 286

def failures
  @failures
end

#timeObject

The time it took to run.



291
292
293
# File 'lib/minitest.rb', line 291

def time
  @time
end

Class Method Details

.inherited(klass) ⇒ Object

:nodoc:



1083
1084
1085
1086
# File 'lib/minitest.rb', line 1083

def self.inherited klass # :nodoc:
  self.runnables << klass
  super
end

.methods_matching(re) ⇒ Object

Returns all instance methods matching the pattern re.



318
319
320
# File 'lib/minitest.rb', line 318

def self.methods_matching re
  public_instance_methods(true).grep(re).map(&:to_s)
end

.on_signal(name, action) ⇒ Object

:nodoc:



397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/minitest.rb', line 397

def self.on_signal name, action # :nodoc:
  supported = SIGNALS[name]

  old_trap = trap name do
    old_trap.call if old_trap.respond_to? :call
    action.call
  end if supported

  yield
ensure
  trap name, old_trap if supported
end

.resetObject

:nodoc:



322
323
324
# File 'lib/minitest.rb', line 322

def self.reset # :nodoc:
  @@runnables = []
end

.run(reporter, options = {}) ⇒ Object

Responsible for running all runnable methods in a given class, each in its own instance. Each instance is passed to the reporter to record.



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/minitest.rb', line 333

def self.run reporter, options = {}
  filtered_methods = if options[:filter]
    filter = options[:filter]
    filter = Regexp.new $1 if filter.is_a?(String) && filter =~ %r%/(.*)/%

    self.runnable_methods.find_all { |m|
      filter === m || filter === "#{self}##{m}"
    }
  else
    self.runnable_methods
  end

  if options[:exclude]
    exclude = options[:exclude]
    exclude = Regexp.new $1 if exclude =~ %r%/(.*)/%

    filtered_methods.delete_if { |m|
      exclude === m || exclude === "#{self}##{m}"
    }
  end

  return if filtered_methods.empty?

  with_info_handler reporter do
    filtered_methods.each do |method_name|
      run_one_method self, method_name, reporter
    end
  end
end

.run_one_method(klass, method_name, reporter) ⇒ Object

Runs a single method and has the reporter record the result. This was considered internal API but is factored out of run so that subclasses can specialize the running of an individual test. See Minitest::ParallelTest::ClassMethods for an example.



369
370
371
372
# File 'lib/minitest.rb', line 369

def self.run_one_method klass, method_name, reporter
  reporter.prerecord klass, method_name
  reporter.record Minitest.run_one_method(klass, method_name)
end

.runnable_methodsObject

Each subclass of Runnable is responsible for overriding this method to return all runnable methods. See #methods_matching.

Raises:

  • (NotImplementedError)


414
415
416
# File 'lib/minitest.rb', line 414

def self.runnable_methods
  raise NotImplementedError, "subclass responsibility"
end

.runnablesObject

Returns all subclasses of Runnable.



421
422
423
# File 'lib/minitest.rb', line 421

def self.runnables
  @@runnables
end

.test_orderObject

Defines the order to run tests (:random by default). Override this or use a convenience method to change it for your tests.



378
379
380
# File 'lib/minitest.rb', line 378

def self.test_order
  :random
end

.with_info_handler(reporter, &block) ⇒ Object

:nodoc:



382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/minitest.rb', line 382

def self.with_info_handler reporter, &block # :nodoc:
  handler = lambda do
    unless reporter.passed? then
      warn "Current results:"
      warn ""
      warn reporter.reporters.first
      warn ""
    end
  end

  on_signal ::Minitest.info_signal, handler, &block
end

Instance Method Details

#failureObject

:nodoc:



441
442
443
# File 'lib/minitest.rb', line 441

def failure # :nodoc:
  self.failures.first
end

#marshal_dumpObject

:nodoc:



427
428
429
430
431
432
433
434
435
# File 'lib/minitest.rb', line 427

def marshal_dump # :nodoc:
  unless @@marshal_dump_warned then
    warn ["Minitest::Runnable#marshal_dump is deprecated.",
          "You might be violating internals. From", caller.first].join " "
    @@marshal_dump_warned = true
  end

  [self.name, self.failures, self.assertions, self.time]
end

#marshal_load(ary) ⇒ Object

:nodoc:



437
438
439
# File 'lib/minitest.rb', line 437

def marshal_load ary # :nodoc:
  self.name, self.failures, self.assertions, self.time = ary
end

#nameObject

Name of the run.



304
305
306
# File 'lib/minitest.rb', line 304

def name
  @NAME
end

#name=(o) ⇒ Object

Set the name of the run.



311
312
313
# File 'lib/minitest.rb', line 311

def name= o
  @NAME = o
end

#passed?Boolean

Did this run pass?

Note: skipped runs are not considered passing, but they don’t cause the process to exit non-zero.

Returns:

  • (Boolean)

Raises:

  • (NotImplementedError)


464
465
466
# File 'lib/minitest.rb', line 464

def passed?
  raise NotImplementedError, "subclass responsibility"
end

#result_codeObject

Returns a single character string to print based on the result of the run. One of ".", "F", "E" or "S".

Raises:

  • (NotImplementedError)


473
474
475
# File 'lib/minitest.rb', line 473

def result_code
  raise NotImplementedError, "subclass responsibility"
end

#runObject

Runs a single method. Needs to return self.

Raises:

  • (NotImplementedError)


454
455
456
# File 'lib/minitest.rb', line 454

def run
  raise NotImplementedError, "subclass responsibility"
end

#skipped?Boolean

Was this run skipped? See #passed? for more information.

Returns:

  • (Boolean)

Raises:

  • (NotImplementedError)


480
481
482
# File 'lib/minitest.rb', line 480

def skipped?
  raise NotImplementedError, "subclass responsibility"
end

#time_itObject

:nodoc:



293
294
295
296
297
298
299
# File 'lib/minitest.rb', line 293

def time_it # :nodoc:
  t0 = Minitest.clock_time

  yield
ensure
  self.time = Minitest.clock_time - t0
end